# -*- coding: utf-8 -*-
"""
Created on Fri Sep  6 08:27:35 2019

@author: 10167232
"""
path = 'data_pickle'
type_list = ['str','function','pandas.core.frame.DataFrame','pandas.core.series.Series','list','dict','int','float','set','tuple']
drop_list = ['In','Out','var_dic_list','get_ipython','']